@@ -3,9 +3,8 @@ use feature ':5.10';
 use strict;
 use warnings;
 use Class::Accessor::Lite;
-use Module::Load;
+use Module::Load '';
 use Time::Piece;
-use Try::Tiny;
 
 use Sisimai::Address;
 use Sisimai::RFC3463;
@@ -87,12 +86,12 @@ sub new {
     }
 
     OTHER_VALUES: {
-        my $v = [ 
+        my @v = ( 
             'listid', 'subject', 'messageid', 'smtpagent', 'diagnosticcode',
             'diagnostictype', 'deliverystatus', 'reason', 'lhost', 'rhost', 
             'smtpcommand', 'feedbacktype', 'action',
-        ];
-        $thing->{ $_ } = $argvs->{ $_ } // '' for @$v;
+        );
+        $thing->{ $_ } = $argvs->{ $_ } // '' for @v;
     }
     return bless( $thing, __PACKAGE__ );
 }
@@ -226,15 +225,11 @@ sub make {
                 $p->{'timezoneoffset'} = $2;
             }
 
-            try {
+            eval {
                 # Convert from the date string to an object then calculate time
                 # zone offset.
                 my $t = Time::Piece->strptime( $datestring, '%a, %d %b %Y %T' );
                 $p->{'timestamp'} = ( $t->epoch - $zoneoffset ) // undef; 
-
-            } catch {
-                # Failed to parse the date string...
-                warn $_;
             };
         }
         next unless $p->{'timestamp'};
@@ -246,7 +241,7 @@ sub make {
                 # Check space character in each value
                 if( $p->{ $e } =~ m/ / ) {
                     # Get the first element
-                    $p->{ $e } = [ split( ' ', $p->{ $e } ) ]->[0];
+                    $p->{ $e } = (split( ' ', $p->{ $e }, 2 ))[0];
                 }
             }
             $p->{'subject'} = $rfc822data->{'subject'} // '';
@@ -313,15 +308,15 @@ sub damn {
     my $self = shift;
     my $data = undef;
 
-    try {
+    eval {
         my $v = {};
-        my $stringdata = [ qw|
+        my @stringdata = ( qw|
             token lhost rhost listid alias reason subject messageid smtpagent 
             smtpcommand destination diagnosticcode senderdomain deliverystatus
             timezoneoffset feedbacktype diagnostictype action|
-        ];
-        
-        for my $e ( @$stringdata ) {
+        );
+
+        for my $e ( @stringdata ) {
             # Copy string data
             $v->{ $e } = $self->$e // '';
         }
@@ -329,9 +324,6 @@ sub damn {
         $v->{'recipient'} = $self->recipient->address;
         $v->{'timestamp'} = $self->timestamp->epoch;
         $data = $v;
-
-    } catch {
-        warn $_;
     };
 
     return $data;
@@ -346,17 +338,11 @@ sub dump {
 
     return undef unless $argv =~ m/\A(?:json|yaml)\z/;
 
-    my $referclass = '';
     my $dumpeddata = '';
+    my $referclass = sprintf( "Sisimai::Data::%s", uc $argv );
 
-    try {
-        $referclass = sprintf( "Sisimai::Data::%s", uc $argv );
-        Module::Load::load $referclass;
-        $dumpeddata = $referclass->dump( $self );
-
-    } catch {
-        warn $_;
-    };
+    eval { Module::Load::load $referclass };
+    $dumpeddata = $referclass->dump( $self );
 
     return $dumpeddata;
 }
