@@ -40,13 +40,13 @@ my $RxErr = {
 };
 
 my $RxTmp = {
-    'systemerror' => qr{
+    'networkerror' => qr{
         # courier/module.esmtp/esmtpclient.c:535| soft_error(del, ctf, "DNS lookup failed.");
         \ADNS[ ]lookup[ ]failed[.]\z
     },
 };
 
-sub version     { '4.0.10' }
+sub version     { '4.0.14' }
 sub description { 'Courier MTA' }
 sub smtpagent   { 'Courier' }
 
@@ -74,7 +74,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
 
     my $longfields = __PACKAGE__->LONGFIELDS;
-    my $stripedtxt = [ split( "\n", $$mbody ) ];
+    my @stripedtxt = split( "\n", $$mbody );
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $commandtxt = '';    # (String) SMTP Command name begin with the string '>>>'
     my $connvalues = 0;     # (Integer) Flag, 1 if all the value of $connheader have been set
@@ -89,14 +89,13 @@ sub scan {
     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     $rfc822head = __PACKAGE__->RFC822HEADERS;
 
-    for my $e ( @$stripedtxt ) {
+    for my $e ( @stripedtxt ) {
         # Read each line between $RxMTA->{'begin'} and $RxMTA->{'rfc822'}.
         if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
             # After "message/rfc822"
-            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
+            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
                 my $lhs = $1;
-                my $rhs = $2;
                 my $whs = lc $lhs;
 
                 $previousfn = '';
@@ -159,7 +158,7 @@ sub scan {
                     $v->{'rhost'} = lc $1;
                     if( $v->{'rhost'} =~ m/ / ) {
                         # Get the first element
-                        $v->{'rhost'} = [ split( ' ', $v->{'rhost'} ) ]->[0];
+                        $v->{'rhost'} = (split( ' ', $v->{'rhost'} ))[0];
                     }
 
                 } elsif( $e =~ m/\A[Ll]ast-[Aa]ttempt-[Dd]ate:[ ]*(.+)\z/ ) {
