@@ -4,7 +4,6 @@ use feature ':5.10';
 use strict;
 use warnings;
 use Encode;
-use Try::Tiny;
 
 my $RxMTA = {
     'begin'   => qr/\A[-]+\s+Failure Reasons\s+[-]+\z/,
@@ -21,7 +20,7 @@ my $RxErr = {
     }x,
 };
 
-sub version     { '4.0.4' }
+sub version     { '4.0.7' }
 sub description { 'Lotus Notes' }
 sub smtpagent   { 'Notes' }
 
@@ -43,7 +42,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
 
     my $longfields = __PACKAGE__->LONGFIELDS;
-    my $stripedtxt = [ split( "\n", $$mbody ) ];
+    my @stripedtxt = split( "\n", $$mbody );
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $characters = '';    # (String) Character set name of the bounce mail
     my $removedmsg = 'MULTIBYTE CHARACTERS HAVE BEEN REMOVED';
@@ -53,7 +52,7 @@ sub scan {
     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     $rfc822head = __PACKAGE__->RFC822HEADERS;
 
-    for my $e ( @$stripedtxt ) {
+    for my $e ( @stripedtxt ) {
         # Read each line between $RxMTA->{'begin'} and $RxMTA->{'rfc822'}.
         next unless length $e;
 
@@ -67,10 +66,9 @@ sub scan {
 
         if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
             # After "message/rfc822"
-            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
+            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
                 my $lhs = $1;
-                my $rhs = $2;
                 my $whs = lc $lhs;
 
                 $previousfn = '';
@@ -119,14 +117,13 @@ sub scan {
                     # Error message is not ISO-8859-1
                     my $s = $e;
                     if( length $characters ) {
-                        try {
-                            # Try to convert string
-                            Encode::from_to( $s, $characters, 'utf8' );
-
-                        } catch {
+                        # Try to convert string
+                        eval { Encode::from_to( $s, $characters, 'utf8' ); };
+                        if( $@ ) {
                             # Failed to convert
                             $s = $removedmsg;
-                        };
+                        }
+
                     } else {
                         $s = $removedmsg;
                     }
