@@ -54,7 +54,7 @@ my $RxErr = {
         # smtp/mta.c:1085|  relay->failstr = "Destination seem to reject all mails";
         Destination[ ]seem[ ]to[ ]reject[ ]all[ ]mails
     }x,
-    'systemerror' => qr{(?>
+    'networkerror' => qr{(?>
         #  smtpd/mta.c:972|  relay->failstr = "Temporary failure in MX lookup";
          Address[ ]family[ ]mismatch[ ]on[ ]destination[ ]MXs
         |All[ ]routes[ ]to[ ]destination[ ]blocked
@@ -75,7 +75,7 @@ my $RxErr = {
     }x,
 };
 
-sub version     { '4.0.8' }
+sub version     { '4.0.11' }
 sub description { 'OpenSMTPD' }
 sub smtpagent   { 'OpenSMTPD' }
 
@@ -99,7 +99,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
 
     my $longfields = __PACKAGE__->LONGFIELDS;
-    my $stripedtxt = [ split( "\n", $$mbody ) ];
+    my @stripedtxt = split( "\n", $$mbody );
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
 
     my $v = undef;
@@ -107,14 +107,13 @@ sub scan {
     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     $rfc822head = __PACKAGE__->RFC822HEADERS;
 
-    for my $e ( @$stripedtxt ) {
+    for my $e ( @stripedtxt ) {
         # Read each line between $RxMTA->{'begin'} and $RxMTA->{'rfc822'}.
         if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
             # After "message/rfc822"
-            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
+            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
                 my $lhs = $1;
-                my $rhs = $2;
                 my $whs = lc $lhs;
 
                 $previousfn = '';
