@@ -96,16 +96,17 @@ my $RxSess = {
     }x,
     'systemerror' => qr{(?>
          bad[ ]interpreter:[ ]No[ ]such[ ]file[ ]or[ ]directory
-        |Sorry(?:
-             [,][ ]I[ ]wasn[']t[ ]able[ ]to[ ]establish[ ]an[ ]SMTP[ ]connection
-            |[,][ ]I[ ]couldn[']t[ ]find[ ]a[ ]mail[ ]exchanger[ ]or[ ]IP[ ]address
-            |[.][ ]Although[ ]I[']m[ ]listed[ ]as[ ]a[ ]best[-]preference[ ]MX[ ]
-                or[ ]A[ ]for[ ]that[ ]host
-            )
         |system[ ]error
         |Unable[ ]to\b
         )
     }x,
+    'networkerror' => qr{Sorry(?:
+         [,][ ]I[ ]wasn[']t[ ]able[ ]to[ ]establish[ ]an[ ]SMTP[ ]connection
+        |[,][ ]I[ ]couldn[']t[ ]find[ ]a[ ]mail[ ]exchanger[ ]or[ ]IP[ ]address
+        |[.][ ]Although[ ]I[']m[ ]listed[ ]as[ ]a[ ]best[-]preference[ ]MX[ ]
+            or[ ]A[ ]for[ ]that[ ]host
+        )
+    }x,
     'systemfull' => 
         qr/Requested action not taken: mailbox unavailable [(]not enough free space[)]/,
 };
@@ -140,7 +141,7 @@ my $RxLDAP = {
 # userunknown + expired
 my $RxOnHold = qr/\A[^ ]+ does not like recipient[.]\s+.+this message has been in the queue too long[.]\z/;
 
-sub version     { '4.0.9' }
+sub version     { '4.0.11' }
 sub description { 'qmail' }
 sub smtpagent   { 'qmail' }
 
@@ -168,7 +169,7 @@ sub scan {
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
     my $previousfn = '';    # (String) Previous field name
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-    my $stripedtxt = [ split( "\n", $$mbody ) ];
+    my @stripedtxt = split( "\n", $$mbody );
     my $longfields = __PACKAGE__->LONGFIELDS;
 
     my $v = undef;
@@ -176,14 +177,13 @@ sub scan {
     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     $rfc822head = __PACKAGE__->RFC822HEADERS;
 
-    for my $e ( @$stripedtxt ) {
+    for my $e ( @stripedtxt ) {
         # Read each line between $RxMTA->{'begin'} and $RxMTA->{'rfc822'}.
         if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
             # After "message/rfc822"
-            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
+            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
                 my $lhs = $1;
-                my $rhs = $2;
                 my $whs = lc $lhs;
 
                 $previousfn = '';
@@ -309,8 +309,8 @@ sub scan {
                     LDAP: for my $r ( keys %$RxLDAP ) {
                         # Verify each regular expression of LDAP errors
                         next unless $e->{'diagnosis'} =~ $RxLDAP->{ $r };
-                       $e->{'reason'} = $r;
-                       last(LDAP);
+                        $e->{'reason'} = $r;
+                        last(LDAP);
                     }
                 }
             }
