@@ -7,46 +7,66 @@ sub text  { 'userunknown' }
 sub match {
     my $class = shift;
     my $argvs = shift // return undef;
-    my $regex = [
-        qr/.+ user unknown/,
-        qr/[#]5[.]1[.]1 bad address/,
-        qr/destination server rejected recipients/,
-        qr/email address does not exist/,
-        qr/invalid mailbox path/,
-        qr/invalid recipient/,		# Linkedin
-        qr/no account by that name here/,
-        qr/no such mailbox/,
-        qr/no such recipient/,
-        qr/no such user here/,
-        qr/no such user/,
-        qr/<.+> not found/,
-        qr/mailbox not present/,
-        qr/mailbox unavailable/,
-        qr/no .+ in name directory/,
-        qr/recipient address rejected: access denied/,
-        qr/recipient address rejected: invalid user/,
-        qr/recipient address rejected: user .+ does not exist/,
-        qr/recipient address rejected: user unknown in[ ].+[ ]table/,
-        qr/recipient address rejected: unknown user/,
-        qr/recipient is not local/,
-        qr/recipient not found/,
-        qr/Requested action not taken: mailbox unavailable/,
-        qr/said: 550[-\s]5[.]1[.]1[ ].+[ ]user[ ]unknown[ ]/,
-        qr/sorry, user unknown/,
-        qr/sorry, no mailbox here by that name/,    # qmail
-        qr/this address no longer accepts mail/,
-        qr/this user doesn[']?t have a .+ account/, # Yahoo!
-        qr/undeliverable address/,
-        qr/unknown address/,
-        qr/unknown local[- ]part/,
-        qr/unknown recipient/,
-        qr/unknown user/,
-        qr/user .+ was not found/,
-        qr/user missing home directory/,
-        qr/user unknown/,
-        qr/vdeliver: invalid or unknown virtual user/,
-    ];
-    return 1 if grep { lc( $argvs ) =~ $_ } @$regex;
+    my $regex = qr{(?>
+         .+[ ]user[ ]unknown
+        |[#]5[.]1[.]1[ ]bad[ ]address
+        |archived[ ]recipient
+        |destination[ ]server[ ]rejected[ ]recipients
+        |email[ ]address[ ]does[ ]not[ ]exist
+        |invalid[ ]mailbox[ ]path
+        |invalid[ ]recipient                 # Linkedin
+        |no[ ]account[ ]by[ ]that[ ]name[ ]here
+        |no[ ]such[ ](?:
+             mailbox
+            |person[ ]at[ ]this[ ]address
+            |recipient
+            |user(?:[ ]here)?
+            )
+        |[<].+[>][ ]not[ ]found
+        |mailbox[ ](?:
+             not[ ]present
+            |not[ ]found
+            |unavailable
+            )
+        |no[ ].+[ ]in[ ]name[ ]directory
+        |recipient[ ](?:
+             .+[ ]was[ ]not[ ]found[ ]in
+            |address[ ]rejected:[ ](?:
+                 access[ ]denied
+                |invalid[ ]user
+                |user[ ].+[ ]does[ ]not[ ]exist
+                |user[ ]unknown[ ]in[ ].+[ ]table
+                |unknown[ ]user
+                )
+            |is[ ]not[ ]local
+            |not[ ]found
+            )
+        |Requested[ ]action[ ]not[ ]taken:[ ]mailbox[ ]unavailable
+        |said:[ ]550[-[ ]]5[.]1[.]1[ ].+[ ]user[ ]unknown[ ]
+        |sorry,[ ](?:
+             user[ ]unknown
+            |no[ ]mailbox[ ]here[ ]by[ ]that[ ]name
+            )
+        |this[ ]address[ ]no[ ]longer[ ]accepts[ ]mail
+        |this[ ]user[ ]doesn[']?t[ ]have[ ]a[ ].+[ ]account
+        |undeliverable[ ]address
+        |unknown[ ](?:
+             address
+            |local[- ]part
+            |recipient
+            |user
+            )
+        |user[ ](?:
+             .+[ ]was[ ]not[ ]found
+            |missing[ ]home[ ]directory
+            |not[ ]found     # 550 User not found. See http://mail.bigmir.net/err/2/
+            |unknown
+            )
+        |vdeliver:[ ]invalid[ ]or[ ]unknown[ ]virtual[ ]user
+        )
+    }xi;
+
+    return 1 if $argvs =~ $regex;
     return 0;
 }
 
